==> estateplat-common-1.2.4-20181024.070702-35-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslSfd.java <==
package cn.gtmap.estateplat.model.acceptance;/*
 * @author <a href="mailto:huangzijian@gtmap.cn">huangzijian</a>
 * @version 1.0, 2018/10/22
 * @description 
 */

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
*@Author:<a href="mailto:huangzijian@gtmap.cn">huangzijian</a>
*@Description: 收费单
*@Date 13:19 2018/10/22
*/
@Entity
@Table( name ="YCSL_SFD" )
public class YcslSfd implements Serializable {
    /**
     * 收费ID
     */
    @Column(name = "SFID" )
    @Id
    private String sfid;
    /**
     * 项目id
     */
    @Column(name = "PROID" )
    private String proid;
    /**
     * 计费基数
     */
    @Column(name = "JFJS" )
    private Integer jfjs;
    /**
     * 比例
     */
    @Column(name = "JFBL" )
    private Double jfbl;
    /**
     * 实收金额
     */
    @Column(name = "SSJE" )
    private Double ssje;
    /**
     * 收款方
     */
    @Column(name = "SKF" )
    private String skf;
    /**
     * 二维码
     */
    @Column(name = "EWM" )
    private String ewm;


    public String getSfid() {
        return sfid;
    }

    public void setSfid(String sfid) {
        this.sfid = sfid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Integer getJfjs() {
        return jfjs;
    }

    public void setJfjs(Integer jfjs) {
        this.jfjs = jfjs;
    }

    public Double getJfbl() {
        return jfbl;
    }

    public void setJfbl(Double jfbl) {
        this.jfbl = jfbl;
    }

    public Double getSsje() {
        return ssje;
    }

    public void setSsje(Double ssje) {
        this.ssje = ssje;
    }

    public String getSkf() {
        return skf;
    }

    public void setSkf(String skf) {
        this.skf = skf;
    }

    public String getEwm() {
        return ewm;
    }

    public void setEwm(String ewm) {
        this.ewm = ewm;
    }
}

==> estateplat-common-1.2.4-20181031.094206-45-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslSfd.java <==
package cn.gtmap.estateplat.model.acceptance;/*
 * @author <a href="mailto:huangzijian@gtmap.cn">huangzijian</a>
 * @version 1.0, 2018/10/22
 * @description 
 */

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
*@Author:<a href="mailto:huangzijian@gtmap.cn">huangzijian</a>
*@Description: 收费单
*@Date 13:19 2018/10/22
*/
@Entity
@Table( name ="YCSL_SFD" )
public class YcslSfd implements Serializable {
    /**
     * 收费ID
     */
    @Column(name = "SFID" )
    @Id
    private String sfid;
    /**
     * 项目id
     */
    @Column(name = "PROID" )
    private String proid;
    /**
     * 计费基数
     */
    @Column(name = "JFJS" )
    private Integer jfjs;
    /**
     * 比例
     */
    @Column(name = "JFBL" )
    private Double jfbl;
    /**
     * 实收金额
     */
    @Column(name = "SSJE" )
    private Double ssje;
    /**
     * 收款方
     */
    @Column(name = "SKF" )
    private String skf;
    /**
     * 二维码
     */
    @Column(name = "EWM" )
    private String ewm;
    /**
     * 土地缴纳金
     */
    @Column(name = "TDJNJ" )
    private Double tdjnj;


    public String getSfid() {
        return sfid;
    }

    public void setSfid(String sfid) {
        this.sfid = sfid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Integer getJfjs() {
        return jfjs;
    }

    public void setJfjs(Integer jfjs) {
        this.jfjs = jfjs;
    }

    public Double getJfbl() {
        return jfbl;
    }

    public void setJfbl(Double jfbl) {
        this.jfbl = jfbl;
    }

    public Double getSsje() {
        return ssje;
    }

    public void setSsje(Double ssje) {
        this.ssje = ssje;
    }

    public String getSkf() {
        return skf;
    }

    public void setSkf(String skf) {
        this.skf = skf;
    }

    public String getEwm() {
        return ewm;
    }

    public void setEwm(String ewm) {
        this.ewm = ewm;
    }

    public Double getTdjnj() {
        return tdjnj;
    }

    public void setTdjnj(Double tdjnj) {
        this.tdjnj = tdjnj;
    }
}
